# Find x-th percentile of sequence without numpy 

[![codecov](https://codecov.io/gh/heaviss/percentiles/branch/master/graph/badge.svg)](https://codecov.io/gh/heaviss/percentiles)
[![CircleCI](https://circleci.com/gh/heaviss/percentiles.svg?style=svg)](https://circleci.com/gh/heaviss/percentiles)

Because sometimes you need one function only.

## Install
```
pip install percentiles
```

## Use
```
todo
```

